
REM ## Our variables
set opensslbindir=C:\OpenSSL-Win64\bin
set testdir=.
set originalsdir=%testdir%\originals
set certsdir=%testdir%\certs
set keysdir=%testdir%\keys
set reqsdir=%testdir%\reqs

REM ## key values RSA or ECC
set key=RSA

REM ## rsasize values 1024,2048,4096
set rsasize=4096

REM ## ecc sizevalues secp256r1,secp384r1,secp521r1
set eccsize=secp521r1

REM ## hash values: sha1,sha256,sha384,sha512
set hash=sha512

REM ## Make our directories
mkdir %testdir%
mkdir %certsdir%
mkdir %keysdir%
mkdir %reqsdir%


REM ## Make the Root CA
if %key%==RSA %opensslbindir%\openssl genrsa -out %keysdir%\rootca.key %rsasize%
if %key%==ECC %opensslbindir%\openssl ecparam -param_enc named_curve -name %eccsize% -genkey -outform PEM -out %keysdir%\rootca.key
%opensslbindir%\openssl req -config openssl.cfg -extensions v3_rootca -subj "/C=US/O=Commercial Certificate Authority/CN=Test Root CA" -new -x509 -set_serial 01 -days 365 -key %keysdir%\rootca.key -out %certsdir%\root.cer

REM ## Make the Partner CA
if %key%==RSA %opensslbindir%\openssl genrsa -out %keysdir%\partnerca.key %rsasize%
if %key%==ECC %opensslbindir%\openssl ecparam -param_enc named_curve -name %eccsize% -genkey -outform PEM -out %keysdir%\partnerca.key
%opensslbindir%\openssl req -new -subj "/C=US/O=Commercial Certificate Authority/CN=Test Partner CA" -key %keysdir%\partnerca.key -out %reqsdir%\partnerca.req
%opensslbindir%\openssl x509 -req -%hash% -extfile openssl.cfg -in %reqsdir%\partnerca.req -CAkey %keysdir%\rootca.key -CA %certsdir%\root.cer -set_serial 02 -days 182 -extensions v3_partnerca -out %certsdir%\partnerca.cer

REM ## Make the Customer CA
if %key%==RSA %opensslbindir%\openssl genrsa -out %keysdir%\customerca.key %rsasize%
if %key%==ECC %opensslbindir%\openssl ecparam -param_enc named_curve -name %eccsize% -genkey -outform PEM -out %keysdir%\customerca.key
%opensslbindir%\openssl req -new -subj "/C=US/O=Manufacturing Business/CN=Customer CA" -key %keysdir%\customerca.key -out %reqsdir%\customerca.req
%opensslbindir%\openssl x509 -req -%hash% -extfile openssl.cfg -in %reqsdir%\customerca.req -CAkey %keysdir%\partnerca.key -CA %certsdir%\partnerca.cer -set_serial 01 -days 91 -extensions v3_customerca -out %certsdir%\customerca.cer

REM ## Make the Customer CA chain
copy %certsdir%\customerca.cer + %certsdir%\partnerca.cer + %certsdir%\root.cer %certsdir%\customercachain.pem

REM ## Make the User Certificate
if %key%==RSA %opensslbindir%\openssl genrsa -out %keysdir%\user.key %rsasize%
if %key%==ECC %opensslbindir%\openssl ecparam -param_enc named_curve -name %eccsize% -genkey -outform PEM -out %keysdir%\user.key
%opensslbindir%\openssl req -new -subj "/C=US/O=Manufacturing Business/CN=John Doe" -key %keysdir%\user.key -out %reqsdir%\user.req
%opensslbindir%\openssl x509 -req -%hash% -extfile openssl.cfg -in %reqsdir%\user.req -CAkey %keysdir%\customerca.key -CA %certsdir%\customerca.cer -set_serial 01 -days 45 -extensions v3_usr_cert -out %certsdir%\user.cer

REM ## Make the User PKCS12
%opensslbindir%\openssl pkcs12 -passout pass:password -export -in %certsdir%\user.cer -inkey %keysdir%\user.key -out %testdir%\user.p12 -name "User Certificate" -certfile %certsdir%\customercachain.pem

REM ## Make the User P7B
%opensslbindir%\openssl crl2pkcs7 -nocrl -certfile %certsdir%\user.cer -out %testdir%\user.p7b -certfile %certsdir%\customercachain.pem -outform DER

REM ## Make the WWW Certificate
if %key%==RSA %opensslbindir%\openssl genrsa -out %keysdir%\www.key %rsasize%
if %key%==ECC %opensslbindir%\openssl ecparam -param_enc named_curve -name %eccsize% -genkey -outform PEM -out %keysdir%\www.key
%opensslbindir%\openssl req -new -subj "/C=US/O=Manufacturing Business/CN=www.example.com" -key %keysdir%\www.key -out %reqsdir%\www.req
%opensslbindir%\openssl x509 -req -%hash% -extfile openssl.cfg -in %reqsdir%\www.req -CAkey %keysdir%\customerca.key -CA %certsdir%\customerca.cer -set_serial 02 -days 45 -extensions v3_www_cert -out %certsdir%\www.cer

REM ## Make the WWW PKCS12
%opensslbindir%\openssl pkcs12 -passout pass:password -export -in %certsdir%\www.cer -inkey %keysdir%\www.key -out %testdir%\www.p12 -name "WWW Certificate" -certfile %certsdir%\customercachain.pem

REM ## Make the WWW P7B
%opensslbindir%\openssl crl2pkcs7 -nocrl -certfile %certsdir%\www.cer -out %testdir%\www.p7b -certfile %certsdir%\customercachain.pem -outform DER

REM ## Make OCSP request and response for WWW
REM start %opensslbindir%\openssl ocsp -index %certsdir%/index.txt -port 81 -rsigner %certsdir%\customerca.cer -rkey %keysdir%\customerca.key -CA %certsdir%\customerca.cer -text -out log.txt -nrequest 1
REM %opensslbindir%\openssl ocsp -issuer %certsdir%\customerca.cer -cert %certsdir%\www.cer -host localhost:81 -resp_text -respout %testdir%\www.ocspresp -reqout %testdir%\www.ocspreq

REM ## Do a web server connection
REM start %opensslbindir%\openssl s_server -www -cert %certsdir%\www.cer -key %keysdir%\www.key -accept 8080
REM start %opensslbindir%\openssl s_client -connect localhost:8080